@@ -1,6 +1,6 @@
 #!/bin/bash -e
 
-for THEME in {human,tangerine,tango}
+for THEME in {human,tangerine,gnome}
 do
 	ID=`cat ../src/custom/$THEME/install.rdf | grep "em:id" | head -n1 | grep -o "{[^ ]*}"`
 	THEMEDIR="src/usr/lib/firefox/extensions/$ID"
