@@ -4,9 +4,9 @@
 	 * theme.
 	 */
 	function patchColors($dir) {
-		// don't replace colors on Tango
+		// don't replace colors on gnome
 		global $theme;
-		if(TANGO == $theme) {
+		if(GNOME == $theme) {
 			return;			
 		}
 
